@@ -6,18 +6,9 @@
  * Date        : 2018-07-30
  * Description : abstract class to define digiKam plugin
  *
- * Copyright (C) 2018-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -26,6 +17,7 @@
 
 // Qt includes
 
+#include <QMap>
 #include <QList>
 #include <QCoreApplication>
 #include <QString>
@@ -40,12 +32,15 @@
 #include "dpluginauthor.h"
 #include "digikam_export.h"
 
-/** The plugin interface identifier definitions shared between DPlugins and Loader to
- *  check the binary compatibility at run-time.
+/**
+ * The plugin interface identifier definitions shared between DPlugins and Loader to
+ * check the binary compatibility at run-time.
  */
-#define DIGIKAM_DPLUGIN_GENERIC_IID "org.kde.digikam.DPluginGeneric/1.1.0"
-#define DIGIKAM_DPLUGIN_EDITOR_IID  "org.kde.digikam.DPluginEditor/1.1.0"
-#define DIGIKAM_DPLUGIN_BQM_IID     "org.kde.digikam.DPluginBqm/1.1.0"
+#define DIGIKAM_DPLUGIN_GENERIC_IID   "org.kde.digikam.DPluginGeneric/1.1.0"
+#define DIGIKAM_DPLUGIN_EDITOR_IID    "org.kde.digikam.DPluginEditor/1.1.0"
+#define DIGIKAM_DPLUGIN_BQM_IID       "org.kde.digikam.DPluginBqm/1.1.0"
+#define DIGIKAM_DPLUGIN_RAWIMPORT_IID "org.kde.digikam.DPluginRawImport/1.1.0"
+#define DIGIKAM_DPLUGIN_DIMG_IID      "org.kde.digikam.DPluginDImg/1.1.0"
 
 namespace Digikam
 {
@@ -112,7 +107,30 @@ public:
      * Plugin method to clean up internal created objects.
      * This method is called by plugin loader.
      */
-    virtual void cleanUp();
+    virtual void cleanUp() {};
+
+    /**
+     * Return the online handbook section corresponding to this plugin.
+     * It's used in plugin dialog Help button.
+     * By default, no section is defined, and root page of the documentation is loaded by Help Button in this case.
+     */
+    virtual QString handbookSection() const;
+
+    /**
+     * Return the online handbook chapter from an handbook section corresponding to this plugin.
+     * It's used in plugin dialog Help button.
+     * By default, no chapter is defined, and root page of the section is loaded by Help Button in this case.
+     * Note: a chapter is always included in a section. See handbookSection() for details.
+     */
+    virtual QString handbookChapter() const;
+
+    /**
+     * Return the online handbook reference from an handbook chapter corresponding to this plugin.
+     * It's used in plugin dialog Help button.
+     * By default, no reference is defined, and root page of the chapter is loaded by Help Button in this case.
+     * Note: a reference is always included in a chapter. See handbookChapter() for details.
+     */
+    virtual QString handbookReference() const;
 
     /**
      * Return true if plugin can be configured in setup dialog about the visibility property.
@@ -151,7 +169,7 @@ public:
 
     /**
      * @brief Returns the unique internal identification property of the plugin.
-     *        Must be formated as "org.kde.digikam.plugin._PLUGIN_TYPE_._NAME_OF_PLUGIN_".
+     *        Must be formatted as "org.kde.digikam.plugin._PLUGIN_TYPE_._NAME_OF_PLUGIN_".
      *        Examples: "org.kde.digikam.plugin.generic.Calendar"
      *                  "org.kde.digikam.plugin.editor.AdjustCurvesTool"
      *                  "org.kde.digikam.plugin.bqm.NoiseReduction"
@@ -160,7 +178,7 @@ public:
 
     /**
      * @brief Returns the unique top level internal identification property of the plugin interface.
-     *        Must be formated as "org.kde.digikam._NAME_OF_INTERFACE_/_VERSION_".
+     *        Must be formatted as "org.kde.digikam._NAME_OF_INTERFACE_/_VERSION_".
      *        Examples: "org.kde.digikam.DPluginGeneric/1.1.0"
      *                  "org.kde.digikam.DPluginEditor/1.1.0"
      *                  "org.kde.digikam.DPluginBqm/1.1.0"
@@ -188,6 +206,21 @@ public:
      */
     virtual QString details() const = 0;
 
+    /**
+     * @brief Returns a map of extra data to show in plugin about dialog.
+     */
+    virtual QMap<QString, QStringList> extraAboutData() const { return QMap<QString, QStringList>(); };
+
+    /**
+     * @brief Returns a list of extra data row titles to show in tab of plugin about dialog.
+     */
+    virtual QStringList extraAboutDataRowTitles() const { return QStringList(); };
+
+    /**
+     * @brief Returns the tab title of data returned by extraAboutData().
+     */
+    virtual QString extraAboutDataTitle() const { return QString(); };
+
 private:
 
     class Private;
